@@ -86,8 +86,8 @@ reconstruct_past_diversification = function(times, 						# numeric vector of siz
 				Ntimes							= Ntimes,
 				total_diversities 				= (if(coalescent) reconstruction$total_diversities else diversities),
 				coalescent_diversities 			= (if(coalescent) diversities else reconstruction$coalescent_diversities),
-				birth_rates 					= reconstruction$birth_rates,
-				death_rates 					= reconstruction$death_rates,
+				birth_rates 					= reconstruction$birth_rates, # these are absolute (total) lineage creation rates, not per-capita rates. To obtain per-capita rates, divide these by total_diversities[]
+				death_rates 					= reconstruction$death_rates, # these are absolute (total) lineage loss rates, not per-capita rates. To obtain per-capita rates, divide these by total_diversities[]
 				Psurvival		 				= Psurvival,
 				Pdiscovery						= Pdiscovery,
 				Prepresentation	 				= Prepresentation,
